@@ -396,7 +396,7 @@ EXCMD(CMD_continue,	"continue",	ex_continue,
 EXCMD(CMD_confirm,	"confirm",	ex_wrongmodifier,
 	EX_NEEDARG|EX_EXTRA|EX_NOTRLCOM|EX_CMDWIN,
 	ADDR_NONE),
-EXCMD(CMD_const,	"const",	ex_const,
+EXCMD(CMD_const,	"const",	ex_let,
 	EX_EXTRA|EX_NOTRLCOM|EX_SBOXOK|EX_CMDWIN,
 	ADDR_NONE),
 EXCMD(CMD_copen,	"copen",	ex_copen,
@@ -447,6 +447,9 @@ EXCMD(CMD_debuggreedy,	"debuggreedy",	ex_debuggreedy,
 EXCMD(CMD_def,		"def",		ex_function,
 	EX_EXTRA|EX_BANG|EX_SBOXOK|EX_CMDWIN,
 	ADDR_NONE),
+EXCMD(CMD_defcompile,	"defcompile",	ex_defcompile,
+	EX_SBOXOK|EX_CMDWIN|EX_TRLBAR,
+	ADDR_NONE),
 EXCMD(CMD_delcommand,	"delcommand",	ex_delcommand,
 	EX_NEEDARG|EX_WORD1|EX_TRLBAR|EX_CMDWIN,
 	ADDR_NONE),
@@ -1838,6 +1841,9 @@ struct exarg
     char_u	*nextcmd;	// next command (NULL if none)
     char_u	*cmd;		// the name of the command (except for :make)
     char_u	**cmdlinep;	// pointer to pointer of allocated cmdline
+#ifdef FEAT_EVAL
+    char_u	*cmdline_tofree; // free later
+#endif
     cmdidx_T	cmdidx;		// the index for the command
     long	argt;		// flags for the command
     int		skip;		// don't execute the command, only parse it
