@@ -920,7 +920,12 @@ gui_x11_key_hit_cb(
     if (ev_press->state & ShiftMask)
 	modifiers |= MOD_MASK_SHIFT;
     if (ev_press->state & ControlMask)
+    {
 	modifiers |= MOD_MASK_CTRL;
+	if (len == 1 && string[0] < 0x20)
+	    // Use the character before applyng CTRL.
+	    string[0] += 0x40;
+    }
     if (ev_press->state & Mod1Mask)
 	modifiers |= MOD_MASK_ALT;
     if (ev_press->state & Mod4Mask)
@@ -933,7 +938,10 @@ gui_x11_key_hit_cb(
     if (len == -3)
 	key = TO_SPECIAL(string[1], string[2]);
     else
-	key = string[0];
+    {
+	string[len] = NUL;
+	key = mb_ptr2char(string);
+    }
     key = simplify_key(key, &modifiers);
     if (key == CSI)
 	key = K_CSI;
@@ -946,8 +954,12 @@ gui_x11_key_hit_cb(
     }
     else
     {
-	string[0] = key;
-	len = 1;
+	len = mb_char2bytes(key, string);
+
+	// Remove the SHIFT modifier for keys where it's already included,
+	// e.g., '(', '!' and '*'.
+	if (!ASCII_ISALPHA(key) && key > 0x20 && key < 0x7f)
+	    modifiers &= ~MOD_MASK_SHIFT;
     }
 
     if (modifiers != 0)
